NestedMultiselectDropdown class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- NestedMultiselectDropdown
Constructors
-
NestedMultiselectDropdown({Key? key, required List<
NestedMultiselectDropdownItem> options, required NestedMultiselectDropdownController controller, EdgeInsets paddingSelectedItems = const EdgeInsets.all(8), double heightDropdownContainer = 50, double heightDropdownContainerDefault = 200, String noItemsText = 'No Items Selected...', TextStyle? noItemsTextStyle, dynamic onChange(List<NestedMultiselectDropdownItem> value)?, bool isExpanded = false, Colors? activeColor, Colors? checkColor, bool hasFilter = false}) -
const
Properties
- activeColor → Colors?
-
Active color of the checkbox
final
- checkColor → Colors?
-
Color of the check inside the checkbox
final
- controller → NestedMultiselectDropdownController
-
Use this controller to get access to internal state of the Multiselect
final
- hasFilter → bool
-
Show a checkbox to filter the list
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heightDropdownContainer → double
-
Height of the Animated Container
This value is only read with the Animated Container set to true because it requires a specific height to work.
If it is not set, will be used the default height as value.
final
- heightDropdownContainerDefault → double
-
Overwrite the default height of the animated container
final
- isExpanded → bool
-
Expand the width of the component
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- noItemsText → String
-
Text to display in case of no items are provided
final
- noItemsTextStyle → TextStyle?
-
Text Style of noItemsText
final
-
onChange
→ dynamic Function(List<
NestedMultiselectDropdownItem> value)? -
Callback to pass the selectedValues to the parent
It's triggered when you add or remove elements from the selected items
Only works with the liveUpdateValues set to true
final
-
options
→ List<
NestedMultiselectDropdownItem> -
The options which a user can see and select
final
- paddingSelectedItems → EdgeInsets
-
Padding Row Selected Items
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< NestedMultiselectDropdown> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited